
HTTP headers added by a front-end
-------

**Description:**

Use these kind of HTTP headers such as a bearer token only if you have authenticated the sever sending
the header to your application.


**Solution:**

Verify that HTTP headers added by a trusted proxy or SSO devices, such as a bearer token, are 
authenticated by the application.

